# HACON
Lots of cyber security tool
# Install
```
pip3 install https://github.com/onuratakan/HACON/archive/master.zip
```
# Usage
```python
from hacon import HACON

HACON.arguments("-h")
```
# Reminder
Important Information and Reminder Information and programs in all repositories are created for testing purposes. Any legal responsibility belongs to the person or organization that uses it.
